<?php
namespace FM\Service;

use FM\Factory\VistoriasFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class VistoriasService {

    protected $connection;
    protected $VistoriasFactory;
    protected $Environment;
    protected $newCode;

    public function __construct (EntityManager $entityManager, VistoriasFactory $VistoriasFactory, Environment $Environment, NewCode $newCode) {
        $this->connection        = $entityManager->getConnection();
        $this->VistoriasFactory  = $VistoriasFactory;
        $this->Environment       = $Environment;
        $this->newCode           = $newCode;
    }

    // Busca nome e local da vistoria
    public function getInspectionsInfo($param){
        $filter = array();
        forEach($param as $ind => $data){
            if($ind == 'TO_CHAR(GCHK.DTHORAAGEND,\'DD/MM/YYYY\')'){
                (strlen($data) == 21) ? $filter[] = $ind.' = '.$data : '';
            }
            else {
                ($data != null) ? $filter[] = $ind.' = '.$data : '';
            }
        }

        if (count($filter) > 0){
            $params = array(
                "FILTER"   => "WHERE ".implode(' and ', $filter)
            );
        }
        else {
            $params = array(
                "FILTER"   => ''
            );
        }

        $operators = $this->VistoriasFactory->getInspectionsInfo($params);
        return $operators;
    }

    // Busca os critérios
    public function getCriteria($params) {
        $operators = $this->VistoriasFactory->getCriteria($params);
        return $operators;
    }

    public function getInspectionNameAndLocal($params) {
        $operators = $this->VistoriasFactory->getInspectionNameAndLocal($params);
        return $operators;
    }

    // Busca as informações da vistoria
    public function getInspectionToUpdate($nrgerenciamentochk, $nratividadechk) {
        $param = array (
            'NRGERENCIAMENTOCHK' => $nrgerenciamentochk,
            'NRATIVIDADECHK' => $nratividadechk
        );

        $operators = $this->VistoriasFactory->getInspectionToUpdate($param);
        return $operators;
    }

    // Edita a vistoria
    public function updateInspection($idSituacaoAgend, $nrgerenciamentochk, $nrcriteriotargerchk, $nrcriteriotargerchks, $nrtarefagerchk, $dsobstarefagerchk, $nratividadechk) {

        $this->connection->beginTransaction();
        try {
           foreach ($nrcriteriotargerchk as $id) {
            $cont = 0;
            $cont2 = 0;
            if ($id['value'] == null || $id['value'] == '') {

            $nrcriteriotargerchk2 = $this->newCode->getCodeByTableName('FCM_CRITERIOTARGERCHK', 20, 1, 10, true);

            $params = array (
            'NRCRITERIOTARGERCHK' => $nrcriteriotargerchk2,
            'NMCRITERIOTARGERCHK' => $id['name'],
            'NRTAREFAGERCHK'      => $nrtarefagerchk
            );

            $this->VistoriasFactory->insertCriterio($params);

            } else {
                foreach ($nrcriteriotargerchks as $criterioId) {
                    if ($id['value'] == $criterioId) {
                        //update alterando idmarcado para S incrementa o cont
                        $paramsUpdt = array(
                        'NRCRITERIOTARGERCHK' => $id['value'],
                        'NRTAREFAGERCHK'      => $nrtarefagerchk,
                        'IDMARCADO'           => 'S'
                        );
                        $this->VistoriasFactory->updateCriterio($paramsUpdt);
                        $cont++;
                    }
                }
                if ($cont == 0 ) {
                    //update alterando idmarcado para N incrementa
                    $paramsUpdt2 = array(
                    'NRCRITERIOTARGERCHK' => $id['value'],
                    'NRTAREFAGERCHK'      => $nrtarefagerchk,
                    'IDMARCADO'           => 'N'
                    );
                    $cont2++;
                    $this->VistoriasFactory->updateCriterio($paramsUpdt2);
                }
            }
        }

        $paramsUpdtNote = array(
        'NRGERENCIAMENTOCHK' => $nrgerenciamentochk,
        'NRTAREFAGERCHK'     => $nrtarefagerchk,
        'DSOBSTAREFAGERCHK'  => $dsobstarefagerchk
        );

        $this->VistoriasFactory->updateNote($paramsUpdtNote);

        $parametros = array(
            "IDSITUACAOGERCHK"   => $idSituacaoAgend,
            "NRGERENCIAMENTOCHK" => $nrgerenciamentochk,
        );
        $this->VistoriasFactory->upStatusInspection($parametros);

        $this->connection->commit();
        $response = "OK";

        } catch (\Exception $e) {
            $this->connection->rollback();
            $response = ($e->getMessage());
        }
        return $response;
        // $operators = $this->VistoriasFactory->updateFCM_FOTOTAREFAGERCHK($param);
        // $operators = $this->VistoriasFactory->updateFCM_GERENCIAMENTOCHK($param);
    }

    // Busca as atividades da vistoria
    public function getActivities($id) {

        $operators = $this->VistoriasFactory->getActivities($id);
        return $operators;
    }


    // Baixa do fileServe o arquivo de documento e salva em uma pasta temporária
    public function downloadDocFileServer($nrseqmoddocfct, $nrorg) {
        $result = array();
        $params = array(
            "NRSEQMODDOCFCT" => $nrseqmoddocfct,
            "NRORG"          => $nrorg
        );

        $documento = $this->modeloDocFactory->getDocumento($params);
        if(count($documento) > 0) {
            $microtime = microtime(true);
            $microtime = str_replace(".", "_", $microtime);

            $documento = $documento[0];
            $fileDir   = $this->fileServerBaseUrl . $documento["DSCAMINHOARQ"];
            $fileName  = $microtime . "_" . str_replace(",", "_", $documento["NMARQUIVO"]);

            $fileDirTemp = $this->FileServerService->downloadDocFileServer($fileDir, $fileName, $nrorg);
            $fileName    = base64_encode($fileName);
            $result = "/downloadArquivo?requestType=Row&row[FILENAME]=" . $fileName . "&row[FILETYPE]=" . $documento["DSTIPO"];
        }

        return $result;
    }

}
?>